@@ -347,15 +347,12 @@ lr_fastestmirror_prepare(LrHandle *handle,
             break;
         }
 
-        LrFastestMirror *mirror = lr_lrfastestmirror_new();
-        mirror->url = url;
-        mirror->curl = curlh;
-
         curlcode = curl_easy_setopt(curlh, CURLOPT_URL, url);
         if (curlcode != CURLE_OK) {
             g_set_error(err, LR_FASTESTMIRROR_ERROR, LRE_CURL,
                         "curl_easy_setopt(_, CURLOPT_URL, %s) failed: %s",
                         url, curl_easy_strerror(curlcode));
+            curl_easy_cleanup(curlh);
             ret = FALSE;
             break;
         }
@@ -365,10 +362,15 @@ lr_fastestmirror_prepare(LrHandle *handle,
             g_set_error(err, LR_FASTESTMIRROR_ERROR, LRE_CURL,
                     "curl_easy_setopt(_, CURLOPT_CONNECT_ONLY, 1) failed: %s",
                     curl_easy_strerror(curlcode));
+            curl_easy_cleanup(curlh);
             ret = FALSE;
             break;
         }
 
+        LrFastestMirror *mirror = lr_lrfastestmirror_new();
+        mirror->url = url;
+        mirror->curl = curlh;
+
         list = g_slist_append(list, mirror);
     }
 
@@ -692,10 +694,28 @@ lr_fastestmirror(LrHandle *handle,
     }
 
     // Sort the mirrors by the connection time
+    //
+    // Note that always picking the single best mirror has undesirable properties like
+    // forcing the user to always pick the single lowest latency mirror regardless of its
+    // actual bandwidth performance, and high density install bases all using fastestmirror
+    // tend to dogpile the single mirror nearest to all of them
+    //
+    // Instead of using a strict sorted list, shuffle all mirrors with lower latency than 2x
+    // the best mirror, to introduce enough entropy to spread the load across nearby mirrors.
+    double bestMirrorLatency = 0;
+    if (lrfastestmirrors != NULL) {
+        bestMirrorLatency = ((LrFastestMirror *)lrfastestmirrors->data)->plain_connect_time;
+    }
+
     for (GSList *elem = lrfastestmirrors; elem; elem = g_slist_next(elem)) {
         LrFastestMirror *mirror = elem->data;
         g_debug("%s: %3.6f : %s", __func__, mirror->plain_connect_time, mirror->url);
-        new_list = g_slist_append(new_list, mirror->url);
+        if (mirror->plain_connect_time >= 0 &&
+            mirror->plain_connect_time < (2.0 * bestMirrorLatency)) { // Shuffle nearby mirrors
+            new_list = g_slist_insert(new_list, mirror->url, g_random_int_range(0, g_slist_length(new_list)+1));
+        } else { // Far away mirrors appended as backup options
+            new_list = g_slist_append(new_list, mirror->url);
+        }
     }
 
     g_slist_free_full(lrfastestmirrors, (GDestroyNotify)lr_lrfastestmirror_free);
@@ -796,7 +816,7 @@ lr_fastestmirror_sort_internalmirrorlists(GSList *handles,
             gchar *host = elem->data;
             for (GSList *ime = mirrors; ime; ime = g_slist_next(ime)) {
                 LrInternalMirror *im = ime->data;
-                gchar *im_host = lr_url_without_path(im->url);
+                _cleanup_free_ gchar *im_host = lr_url_without_path(im->url);
                 if (!g_strcmp0(im_host, host)) {
                     new_list = g_slist_prepend(new_list, im);
                     // XXX: Maybe convert GSList to GList to make
