@@ -90,6 +90,17 @@ Version contants
 
     *String or None*. Set username and password for HTTP authentication.
     Param must be in format 'username:password'.
+    The user and password strings are not URL decoded, so there is no way to send in
+    a username containing a colon using this option. The option is DEPRECATED!
+    Use LRO_USERNAME and LRO_PASSWORD.
+
+.. data:: LRO_USERNAME
+
+    *String or None*. Set username for HTTP authentication.
+
+.. data:: LRO_PASSWORD
+
+    *String or None*. Set password for HTTP authentication.
 
 .. data:: LRO_PROXY
 
@@ -116,6 +127,8 @@ Version contants
 
     *String or None*. Set username and password for proxy
     authentication in format 'username:password'.
+    Both the username and the password are URL decoded before use, so if the username
+    contains, for example, a colon, it should be encoded as %3A.
 
 .. data:: LRO_PROGRESSCB
 
@@ -400,12 +413,12 @@ Version contants
 
 .. data:: LRO_HTTPAUTHMETHODS
 
-    *Long (bitmask)* Bitmask which tell Librepo which auth metods to use.
+    *Long (bitmask)* Bitmask which tell Librepo which auth methods to use.
     See: :ref:`auth-methods-label`
 
 .. data:: LRO_PROXYAUTHMETHODS
 
-    *Long (bitmask)* Bitmask which tell Librepo which auth metods to use
+    *Long (bitmask)* Bitmask which tell Librepo which auth methods to use
     for proxy authentication.
     See: :ref:`auth-methods-label`
 
@@ -1259,6 +1272,14 @@ class Handle(_librepo.Handle):
 
         See: :data:`.LRO_USERPWD`
 
+    .. attribute:: username:
+
+        See: :data:`.LRO_USERNAME`
+
+    .. attribute:: password:
+
+        See: :data:`.LRO_PASSWORD`
+
     .. attribute:: proxy:
 
         See: :data:`.LRO_PROXY`
